import BaseCurdEntry from './BaseCurdEntry'
import DataTimeRange from '@@/utils/DataTimeRange'
import TagType from './TagType'
import TagPurchaseState from './TagPurchaseState'
import Provider from './Provider'

import tagPurchaseApi from '@@/api/TagPurchaseApi'

export default class TagPurchase extends BaseCurdEntry {
  id

  dataTime = new Date().format('YYYY/MM/DD')
  get formatDataTime () {
    return new Date(this.dataTime).format('YYYY-MM-DD')
  }

  orderNo = ''

  providerId = ''

  tagTypeId
  get tagTypeName () {
    const config = TagPurchase.$$optionData.TagType
    if (config) {
      const option = config.map[this.tagTypeId]
      if (option) {
        return option[TagType.$$nameProp]
      }
    }

    return ''
  }

  number = null

  amount = null

  buyerName

  receiveDate
  get formatReceiveDate () {
    const { receiveDate } = this
    return receiveDate ? new Date(receiveDate).format('YYYY-MM-DD') : ''
  }

  tagPurchaseStateId
  get tagPurchaseStateName () {
    const config = TagPurchase.$$optionData.TagPurchaseState
    if (config) {
      const option = config.map[this.tagPurchaseStateId]
      if (option) {
        return option[TagPurchaseState.$$nameProp]
      }
    }

    return ''
  }

  constructor (editorInstance) {
    super()

    const { optionGroup } = editorInstance

    const providerConfig = optionGroup.Provider
    const [ provider ] = providerConfig.list
    if (provider) {
      this.providerId = provider[providerConfig.Target.$$idProp]
    }

    const tagTypeConfig = optionGroup.TagType
    const tagTypeTarget = tagTypeConfig.Target
    this.infos = tagTypeConfig.list.map(tagType => ({
      tagTypeId: tagType[tagTypeTarget.$$idProp],
      tagTypeName: tagType[tagTypeTarget.$$nameProp],
      number: null
    }))
  }

  static get $$api () {
    return tagPurchaseApi
  }

  static $$getQuery = () => ({
    ...(new DataTimeRange({
      unit: 'Date',
      diff: 7,
      offset: 0
    })),
    tagPurchaseStateId: '',
    order: [['dataTime', 'DESC']]
  })

  static $$optionTargetConfigGroup = [
    [{
      Target: TagType
    }, {
      Target: TagPurchaseState,
      setQuery: (options, query, Target) => {
        const [ option ] = options
        if (option) {
          query.tagPurchaseStateId = option[Target.$$idProp]
        }
      }
    }, {
      Target: Provider
    }]
  ]

  static $$optionData = {}
}
